parse

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Option

type Option = func(o *options)

type Parser

type Parser interface {
	parse.Parser
	//Init initialises the parser with a value of reflected go structure.
	jsonschema.JSONSchemaAble
	Init(value reflect.Value)
	Reset()
}

Parser is a parser for a reflected go structure.

func NewParser

func NewParser(options ...Option) Parser

NewParser returns a new reflect parser.

Jump to