Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Parser ¶
type Parser interface {
parse.Parser
//Init initialises the parser with a value of reflected go structure.
jsonschema.JSONSchemaAble
Init(value reflect.Value)
Reset()
}
Parser is a parser for a reflected go structure.
Click to show internal directories.
Click to hide internal directories.